/***********************************************************************/
/*!
 *  \file       player.h
 *  \brief      demo player for playing PT3 using SDCC
 *  \author     Shining \n
 *           
 *
 *  \b Project: Playcity PT3-Support for SDCC \n
 *
 *  \date       20.12.2014 - File created
 *  \date       00.00.2010 - yy
 *  
 *  \version 1.0
 *
 ***********************************************************************/
 
#ifndef __PLAYER_H__
#define __PLAYER_H__

////////////////////////////////////////////////////////////////////////
// Global defines
////////////////////////////////////////////////////////////////////////
#define NUM_COLORS 16		// mode 0 has 16 colours
#define TRUE 1				// Generic define for true	
#define FALSE 0				// Generic define for false	
#define VALID_PT3_FILES 20	// Max. PT3-Songs for this demo are 20
#define KEYBOARD_HW_LINES 10


////////////////////////////////////////////////////////////////////////
// Global variables
////////////////////////////////////////////////////////////////////////
unsigned char ucCATalogue[2048];				// Contains the catalogue-content after amsdos call
unsigned char ucCATValidPT3[VALID_PT3_FILES]; 	// A list containing all file- indexes with a .pt3- ending
unsigned char* songPart1StartAddress = 0;		// Start-Address for Song-Part 1
unsigned char* songPart2StartAddress = 0;		// Start-Address for Song-Part 2
unsigned short songlen=0;						// length in bytes of a song-file
unsigned char ucActualFile[12];
const unsigned char Palette[NUM_COLORS] = {0, 26, 15, 6, 24, 3, 12, 26, 24, 8, 9, 10, 11,13,14,15};
const unsigned char FirmwarePalette[27] = 
//PEN: 0    1    2    3    4    5    6    7    8    9   10   11   12   13   14   15   16   17   18   19   20   21   22   23   24   25   26
	{0x54,0x44,0x55,0x5C,0x58,0x5D,0x4C,0x45,0x4D,0x56,0x46,0x57,0x5E,0x40,0x5F,0x4E,0x47,0x4F,0x52,0x42,0x53,0x5A,0x59,0x5B,0x4A,0x43,0x4B};


////////////////////////////////////////////////////////////////////////
// Enumeration to identify each physical key
////////////////////////////////////////////////////////////////////////
typedef enum E_Key
{
  Key_CursorUp = 0,
  Key_CursorRight,
  Key_CursorDown,
  Key_F9,
  Key_F6,
  Key_F3,
  Key_Enter,
  Key_FDot,
  Key_CursorLeft, //8
  Key_Copy,
  Key_F7,
  Key_F8,
  Key_F5,
  Key_F1,
  Key_F2,
  Key_F0,
  Key_Clr, //16
  Key_BraceOpen,
  Key_Return,
  Key_BraceClose,
  Key_F4,
  Key_Shift,
  Key_BackSlash,
  Key_Control,
  Key_Caret, //24
  Key_Hyphen,
  Key_At,
  Key_P,
  Key_SemiColon,
  Key_Colon,
  Key_Slash,
  Key_Dot,
  Key_0, //32
  Key_9,
  Key_O,
  Key_I,
  Key_L,
  Key_K,
  Key_M,
  Key_Comma,
  Key_8, //40
  Key_7,
  Key_U,
  Key_Y,
  Key_H,
  Key_J,
  Key_N,
  Key_Space,
  Key_6_Joy2Up, //48
  Key_5_Joy2Down,
  Key_R_Joy2Left,
  Key_T_Joy2Right,
  Key_G_Joy2Fire,
  Key_F,
  Key_B,
  Key_V,
  Key_4, //56
  Key_3,
  Key_E,
  Key_W,
  Key_S,
  Key_D,
  Key_C,
  Key_X,
  Key_1, //64
  Key_2,
  Key_Esc,
  Key_Q,
  Key_Tab,
  Key_A,
  Key_CapsLock,
  Key_Z,
  Key_Joy1Up, //72
  Key_Joy1Down,
  Key_Joy1Left,
  Key_Joy1Right,
  Key_Joy1Fire1,
  Key_Joy1Fire2,
  Key_Joy1Fire3,
  Key_Del,
  Key_Max //80
}; // typedef enum E_Key

#endif // __PLAYER_H__